.. hmf documentation master file, created by
   sphinx-quickstart on Mon Dec  2 10:40:08 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root "toctree" directive.

.. include:: ../README.rst


Contents
--------
.. toctree::
   :maxdepth: 1

   installation
   tutorials
   license
   api
   changelog
   contributors

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
